@@ -1,14 +1,14 @@
 from typing import List, Optional, Dict, Tuple, Union
 from ..application.assembler import Assembler
 from .entity import (
-    Bootstrap,
+    BootstrapInfo,
     ClusterConfig,
     ClusterConfigData,
     DatapipeDataInfo,
     DatapipeServerInfo
 )
 from .dto import (
-    BootstrapDTO,
+    BootstrapInfoDTO,
     ClusterConfigDTO,
     ClusterConfigDataDTO,
     DatapipeDataInfoDTO,
@@ -94,19 +94,19 @@ cluster_config_assembler=ClusterConfigAssembler()
 
 
 
-class BootstrapAssembler(Assembler):
-    def to_entity(self, dto: BootstrapDTO):
-        return Bootstrap(
+class BootstrapInfoAssembler(Assembler):
+    def to_entity(self, dto: BootstrapInfoDTO):
+        return BootstrapInfo(
             cluster_config = cluster_config_assembler.to_entity(dto.cluster_config),
             template = UStr(dto.template),
             platform = UStr(dto.platform),
             patch_setting = None if dto.patch_setting is None else UDict(dto.patch_setting)
         )
-    def to_dto(self, x:Bootstrap):
-        return BootstrapDTO(
+    def to_dto(self, x:BootstrapInfo):
+        return BootstrapInfoDTO(
             cluster_config = cluster_config_assembler.to_do(x.cluster_config),
             template = x.template.get_value(),
             platform = x.platform.get_value(),
             patch_setting = None if x.patch_setting is None else x.patch_setting.get_value()
         )
-bootstrap_assembler=BootstrapAssembler()
+bootstrap_info_assembler=BootstrapInfoAssembler()
