@@ -1,14 +1,14 @@
 from typing import List, Optional, Dict, Tuple, Union
 from ..infrastructure.converter import Converter
 from .entity import (
-    Bootstrap,
+    BootstrapInfo,
     ClusterConfig,
     ClusterConfigData,
     DatapipeDataInfo,
     DatapipeServerInfo
 )
 from .do import (
-    BootstrapDO,
+    BootstrapInfoDO,
     ClusterConfigDO,
     ClusterConfigDataDO,
     DatapipeDataInfoDO,
@@ -94,19 +94,19 @@ cluster_config_converter=ClusterConfigConverter()
 
 
 
-class BootstrapConverter(Converter):
-    def to_entity(self, do: BootstrapDO):
-        return Bootstrap(
+class BootstrapInfoConverter(Converter):
+    def to_entity(self, do: BootstrapInfoDO):
+        return BootstrapInfo(
             cluster_config = cluster_config_converter.to_entity(do.cluster_config),
             template = UStr(do.template),
             platform = UStr(do.platform),
             patch_setting = None if do.patch_setting is None else UDict(do.patch_setting)
         )
-    def to_do(self, x:Bootstrap):
-        return BootstrapDO(
+    def to_do(self, x:BootstrapInfo):
+        return BootstrapInfoDO(
             cluster_config = cluster_config_converter.to_do(x.cluster_config),
             template = x.template.get_value(),
             platform = x.platform.get_value(),
             patch_setting = None if x.patch_setting is None else x.patch_setting.get_value()
         )
-bootstrap_converter=BootstrapConverter()
+bootstrap_info_converter=BootstrapInfoConverter()
