@@ -33,7 +33,7 @@ class ClusterConfigDO(BaseModel):
 
 
 
-class BootstrapDO(BaseModel):
+class BootstrapInfoDO(BaseModel):
     cluster_config: ClusterConfigDO
     template: str = 'normal'
     platform: str = 'aliyun'
