@@ -33,7 +33,7 @@ class ClusterConfigDTO(BaseModel):
 
 
 
-class BootstrapDTO(BaseModel):
+class BootstrapInfoDTO(BaseModel):
     cluster_config: ClusterConfigDTO
     template: str = 'normal'
     platform: str = 'aliyun'
